export(grf)
export(grf.bw)
export(random.test.data)
export(rf.mtry.optim)

S3method(predict, grf)

importFrom("ranger", "ranger")
importFrom("stats", "cor", "dist", "formula", "predict", "sd", "setNames",
           "terms", "rnorm", "rpois", "runif")
importFrom("graphics", "abline", "par", "plot")
importFrom("utils", "setTxtProgressBar", "txtProgressBar")
